package gui;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;

import logika_igre.*;

public class XOFrame extends JFrame {
	private KontrolerIgre kontrolerIgre;
	private XOButton[][] dugmici;
	private Color defaultColor;
	private JLabel labela;
	
	public XOFrame() {
		setBounds(100, 100, 800, 800);
		setVisible(true);
		setDefaultCloseOperation(EXIT_ON_CLOSE);
		kontrolerIgre = new KontrolerIgre();
		
		setGUI();
		
		pack();
		
		inicijalizujIgru();
	}
	
	String getPoruka(StatusIgre status) {
		if(status == StatusIgre.NERESENO) 
			return "Nereseno je.";
		
		if(status == StatusIgre.POBEDIO_X) 
			return "Pobedio je X.";
		
		return "Pobedio je O.";
	}
	
	public void setGUI() {
		dugmici = new XOButton[3][3];
		defaultColor = new JButton().getBackground();
		
		JPanel tabela = new JPanel(new GridLayout(3, 3));
		getContentPane().add(tabela, BorderLayout.CENTER);
		labela = new JLabel("Na potezu je X");
		JPanel northPanel = new JPanel(new FlowLayout());
		northPanel.add(labela);
		getContentPane().add(northPanel, BorderLayout.NORTH);
		
		XOButton dugme;
	
		ActionListener action = new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				XOButton dugme = (XOButton) e.getSource();
				kontrolerIgre.odigrajPotez(dugme.x, dugme.y);
				nacrtaj();
				
				StatusIgre statusIgre = kontrolerIgre.getStatusIgre();
				if(statusIgre == StatusIgre.U_TOKU) {
					labela.setText("Na potezu je " + kontrolerIgre.getNaPotezu());
					return;
				}

				String poruka = getPoruka(statusIgre) + "Da li zelite da zapocnete novu igru?";
				int dialogResult = JOptionPane.showConfirmDialog(null, poruka, "Kraj igre", JOptionPane.YES_NO_OPTION);
				if(dialogResult == JOptionPane.YES_OPTION) {
					inicijalizujIgru();
				} else {
					System.exit(0);
				}
			}
		};
		
		for(int i = 0; i < 3; i++) {
			for(int j = 0; j < 3; j++) {
				dugme = new XOButton(i, j);
				dugme.addActionListener(action);
				tabela.add(dugme);
				dugmici[i][j] = dugme;
			}
		}
	}
	
	private void inicijalizujIgru() {
		kontrolerIgre.inicijalizujIgru();
		labela.setText("Na potezu je X");
		nacrtaj();
	}
	
	private void nacrtaj() {
		XOButton dugme;
		for(int i = 0; i < 3; i++) {
			for(int j = 0; j < 3; j++) {
				dugme = dugmici[i][j];
				int polje = kontrolerIgre.getPolje(i, j);
				String text = "";
				if(polje == KontrolerIgre.X) {
					text = "X";
				} else if(polje == KontrolerIgre.O) {
					text = "O";
				}
				dugme.setText(text);
				if(text != "") {
					dugme.setBackground(Color.WHITE);
				} else {
					dugme.setBackground(defaultColor);
				}
			}
		}
	}
}
