package logika_igre;

public class KontrolerIgre {
	public static final int X = 1;
	public static final int O = -1;
	public static final int PRAZNO = 0;
	private int[][] tabla;
	private int brojOdigranihPoteza;
	private int naPotezu;
	
	public KontrolerIgre() {
		tabla = new int[3][3];
		inicijalizujIgru();
	}
	
	public void inicijalizujIgru() {
		brojOdigranihPoteza = 0;
		naPotezu = X;
		for(int i = 0; i < 3; i++) {
			for(int j = 0; j < 3; j++) {
				tabla[i][j] = PRAZNO;
			}
		}
	}
	
	private boolean vanOpsega(int x, int a, int b) {
		return x < a || x > b;
	}
	
	public int getPolje(int x, int y) {
		if(vanOpsega(x, 0, 2) || vanOpsega(y, 0, 2))
			throw new RuntimeException();
		return tabla[x][y];
	}
	
	public boolean odigrajPotez(int x, int y) {
		if(vanOpsega(x, 0, 2) || vanOpsega(y, 0, 2))
			return false;
		
		if(tabla[x][y] != PRAZNO)
			return false;
		
		tabla[x][y] = naPotezu;
		
		if(naPotezu == X) {
			naPotezu = O;
		} else {
			naPotezu = X;
		}
		
		brojOdigranihPoteza++;
		
		return true;
	}
	
	public StatusIgre getStatusIgre() {
		int suma;
		
		// provera vrsta
		for(int i = 0; i < 3; i++) {
			suma = 0;
			
			for(int j = 0; j < 3; j++) {
				suma += tabla[i][j];
			}
			
			if(suma == 3 * X)
				return StatusIgre.POBEDIO_X;
			
			if(suma == 3 * O)
				return StatusIgre.POBEDIO_O;
				
		}
		
		// provera kolona
		for(int i = 0; i < 3; i++) {
			suma = 0;
			
			for(int j = 0; j < 3; j++) {
				suma += tabla[j][i];
			}
			
			if(suma == 3 * X)
				return StatusIgre.POBEDIO_X;
			
			if(suma == 3 * O)
				return StatusIgre.POBEDIO_O;
		}
		
		// provera glavne dijagonale
		suma = 0;
		
		for(int i = 0; i < 3; i++) {
			suma += tabla[i][i];
		}
		
		if(suma == 3 * X)
			return StatusIgre.POBEDIO_X;
		
		if(suma == 3 * O)
			return StatusIgre.POBEDIO_O;
		
		// provera sporedne dijagonale
		suma = 0;
		
		for(int i = 0; i < 3; i++) {
			suma += tabla[i][2 - i];
		}
		
		if(suma == 3 * X)
			return StatusIgre.POBEDIO_X;
		
		if(suma == 3 * O)
			return StatusIgre.POBEDIO_O;
		
		if(brojOdigranihPoteza == 9)
			return StatusIgre.NERESENO;
		
		
		return StatusIgre.U_TOKU;
	}
	
	public String getNaPotezu() {
		if(naPotezu == X)
			return "X";
		return "O";
	}
}
